@@ -23,7 +23,7 @@ class JPTest:
     """
     TESTS: List['JPTest'] = []
 
-    def __init__(self, name: str = None, max_score: Union[float, int] = None, timeout: int = 120,
+    def __init__(self, name: str = None, max_score: Union[float, int] = 0, timeout: int = 120,
                  execute: EXECUTE_TYPE = None):
         """
         :param name: name used in the output
@@ -33,7 +33,7 @@ class JPTest:
         """
 
         self.name: str = name
-        self.max_score: float = float(max_score) if max_score is not None else None
+        self.max_score: float = float(max_score)
         self.timeout: int = timeout
 
         self._fun: JPTestFunction
